==> kubernetes-model-events-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/events/v1beta1/EventListFluent.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EventListFluent<A extends EventListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Event item);
  public A setToItems(Integer index,Event item);
  public A addToItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public A addAllToItems(Collection<Event> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public A removeAllFromItems(Collection<Event> items);
  public A removeMatchingFromItems(Predicate<EventBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Event> getItems();
  public List<Event> buildItems();
  public Event buildItem(Integer index);
  public Event buildFirstItem();
  public Event buildLastItem();
  public Event buildMatchingItem(Predicate<EventBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<EventBuilder> predicate);
  public A withItems(List<Event> items);
  public A withItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public Boolean hasItems();
  public EventListFluent.ItemsNested<A> addNewItem();
  public EventListFluent.ItemsNested<A> addNewItemLike(Event item);
  public EventListFluent.ItemsNested<A> setNewItemLike(Integer index,Event item);
  public EventListFluent.ItemsNested<A> editItem(Integer index);
  public EventListFluent.ItemsNested<A> editFirstItem();
  public EventListFluent.ItemsNested<A> editLastItem();
  public EventListFluent.ItemsNested<A> editMatchingItem(Predicate<EventBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,EventFluent<EventListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-events-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/events/v1beta1/EventListFluent.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EventListFluent<A extends EventListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Event item);
  public A setToItems(int index,Event item);
  public A addToItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public A addAllToItems(Collection<Event> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public A removeAllFromItems(Collection<Event> items);
  public A removeMatchingFromItems(Predicate<EventBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Event> getItems();
  public List<Event> buildItems();
  public Event buildItem(int index);
  public Event buildFirstItem();
  public Event buildLastItem();
  public Event buildMatchingItem(Predicate<EventBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<EventBuilder> predicate);
  public A withItems(List<Event> items);
  public A withItems(io.fabric8.kubernetes.api.model.events.v1beta1.Event... items);
  public Boolean hasItems();
  public EventListFluent.ItemsNested<A> addNewItem();
  public EventListFluent.ItemsNested<A> addNewItemLike(Event item);
  public EventListFluent.ItemsNested<A> setNewItemLike(int index,Event item);
  public EventListFluent.ItemsNested<A> editItem(int index);
  public EventListFluent.ItemsNested<A> editFirstItem();
  public EventListFluent.ItemsNested<A> editLastItem();
  public EventListFluent.ItemsNested<A> editMatchingItem(Predicate<EventBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,EventFluent<EventListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
